@@ -6,7 +6,7 @@ import pytz
 from pytz import timezone
 from dateutil.relativedelta import relativedelta
 
-from .exceptions import DeloreanInvalidTimezone, DeloreanInvalidDatetime
+from .exceptions import DeloreanInvalidTimezone
 
 UTC = "UTC"
 utc = timezone("UTC")
@@ -194,6 +194,18 @@ class Delorean(object):
             return self._dt == other._dt and self._tz == other._tz
         return False
 
+    def __lt__(self, other):
+        return self.epoch() < other.epoch()
+
+    def __gt__(self, other):
+        return self.epoch() > other.epoch()
+
+    def __ge__(self, other):
+        return self.epoch() >= other.epoch()
+
+    def __le__(self, other):
+        return self.epoch() <= other.epoch()
+
     def __ne__(self, other):
         return not self == other
 
